AIOHappyBase
============

.. image:: https://readthedocs.org/projects/aiohappybase/badge/?version=latest
   :target: https://aiohappybase.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://github.com/aiudirog/aiohappybase/workflows/test/badge.svg
   :target: https://github.com/aiudirog/aiohappybase
   :alt: Workflow Status

.. image:: https://codecov.io/gh/aiudirog/aiohappybase/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/aiudirog/aiohappybase

**AIOHappyBase** is a developer-friendly Python_ library to interact asynchronously with Apache
HBase_. It is a fork of the original `HappyBase <https://github.com/wbolster/happybase>`_ library aiming to deliver a very similar API.

* `Documentation <https://aiohappybase.readthedocs.io/>`_ (Docs)
* `Downloads <http://pypi.python.org/pypi/aiohappybase/>`_ (PyPI) (TODO)
* `Source code <https://github.com/aiudirog/aiohappybase>`_ (Github)

.. _Python: http://python.org/
.. _HBase: http://hbase.apache.org/

.. If you're reading this from the README.rst file in a source tree,
   you can generate the HTML documentation by running "make doc" and browsing
   to doc/build/html/index.html to see the result.
